<?php

////////////////////////////////////////////////////////////////////////
//
// Function definitions necessary to create XML/VOTABLE files.
//
///////////////////////////////////////////////////////////////////////

function print_column_headers_VO() {

  /// PRINT VOTABLE HEADERS (<FIELD>) FOR EACH OF THE COLUMNS TO BE INCLUDED

  echo "<FIELD name=\"Filename\" ID=\"col1\" ucd=\"meta.id;meta.main\" datatype=\"char\" arraysize=\"30\">\n";
  echo " <DESCRIPTION>\n  This is the name of the PSRFITS file at this position.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Target Name\" ID=\"col2\" ucd=\"obs.field;meta.id\" datatype=\"char\" arraysize=\"20\">\n";
  echo " <DESCRIPTION>\n  This is the name of the PSRFITS file at this position.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Survey\" ID=\"col3\" ucd=\"obs;meta.dataset;meta.id\" datatype=\"char\" arraysize=\"10\">\n";
  echo " <DESCRIPTION>\n  The short code for the survey type: PKS70=70cm Parkes Southern Pulsar Survey; PM=Parkes Multibeam Pulsar Survey, PH=Parkes High-Latitude Pulsar Survey; blank means not part of a survey or unknown.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"RA\" ID=\"col4\" ucd=\"pos.eq.ra;meta.main\" ref=\"J2000\" datatype=\"double\" width=\"10\" precision=\"6\" unit=\"deg\">\n";
  echo " <DESCRIPTION>\n  The Right Ascension of the central position of the pointing.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"DEC\" ID=\"col5\" ucd=\"pos.eq.dec;meta.main\" ref=\"J2000\" datatype=\"double\" width=\"11\" precision=\"6\" unit=\"deg\">\n";
  echo " <DESCRIPTION>\n  The Declination of the central position of the pointing.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"BMAJ\" ID=\"col6\" ucd=\"pos.angResolution;phys.angSize.smajAxis\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo " <DESCRIPTION>\n  The full-width-half-maximum (FWHM) of the major-axis of the beam.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"BMIN\" ID=\"col7\" ucd=\"pos.angResolution;phys.angSize.sminAxis\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo " <DESCRIPTION>\n  The full-width-half-maximum (FWHM) of the minor-axis of the beam.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"BPA\" ID=\"col8\" ucd=\"pos.angResolution;pos.posAng\" datatype=\"float\" width=\"6\" precision=\"4\" unit=\"deg\">\n";
  echo " <DESCRIPTION>\n  The position angle of the beam.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"UT Date/Time of Observations\" ID=\"col9\" ucd=\"time.start\" datatype=\"char\" arraysize=\"30\">\n";
  echo " <DESCRIPTION>\n  The UT Date and Time of the start of the observations, in FITS DATE-OBS format.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"MJD\" ID=\"col10\" ucd=\"time.start\" datatype=\"double\" width=\"14\" precision=\"8\">\n";
  echo " <DESCRIPTION>\n  The Modified Julian Date of the observation.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"ObsFreq\" ID=\"col11\" ucd=\"em.freq.central\" datatype=\"double\" width=\"9\" precision=\"4\" unit=\"MHz\">\n";
  echo " <DESCRIPTION>\n  The central observing frequency.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Channel Bandwidth\" ID=\"col12\" ucd=\"spect.binSize;em.freq\" datatype=\"double\" width=\"9\" precision=\"4\" unit=\"MHz\">\n";
  echo " <DESCRIPTION>\n  The frequency width of each channel.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Number of Channels\" ID=\"col13\" ucd=\"em.bin;meta.number\" datatype=\"int\" width=\"6\">\n";
  echo " <DESCRIPTION>\n  The number of frequency channels.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Scan length\" ID=\"col14\" ucd=\"obs.exposure;time.duration\" datatype=\"float\" width=\"9\" precision=\"4\" unit=\"s\">\n";
  echo " <DESCRIPTION>\n  The total length of time taken for this observation.\n </DESCRIPTION>\n</FIELD>\n";
  
  echo "<FIELD name=\"Sample time\" ID=\"col15\" ucd=\"time.resolution\" datatype=\"float\" width=\"9\" precision=\"4\" unit=\"s\">\n";
  echo " <DESCRIPTION>\n  The time for each sample in the observation.\n </DESCRIPTION>\n</FIELD>\n";
   
}

function print_data_VO($all_results) {
  
  echo "<DATA>\n<TABLEDATA>\n";
  for ($i=0; $i < count($all_results); $i++) {
    $line = $all_results[$i];
    print_data_line_VO($line);
  }
  echo "</TABLEDATA>\n</DATA>\n";

}

function print_data_line_VO($line) {
  // PRINT A SINGLE ROW OF DATA TO THE VOTABLE
  echo "<TR>\n ";
  printf("<TD>%s</TD>",$line['filename']);
  printf("<TD>%s</TD>",$line['src_name']);
  printf("<TD>%s</TD>",$line['survey']);
  printf("<TD>%10.6f</TD>",$line['rajd']);
  printf("<TD>%+11.6f</TD>",$line['decjd']);
  printf("<TD>%6.4f</TD>",$line['bmaj']);
  printf("<TD>%6.4f</TD>",$line['bmin']);
  printf("<TD>%6.4f</TD>",$line['bpa']);
  printf("<TD>%s</TD>",$line['date_obs']);
  printf("<TD>%14.8f</TD>",$line['mjd']);
  printf("<TD>%9.4f</TD>",$line['obsfreq']);
  printf("<TD>%9.4f</TD>",$line['chanbw']);
  printf("<TD>%d</TD>",$line['nchan']);
  printf("<TD>%9.4f</TD>",$line['scanlen']);
  printf("<TD>%9.4f</TD>",$line['tsamp']);
  echo "\n</TR>\n";
}

?>
